@@ -5,7 +5,8 @@ from unittest import TestCase, skipUnless
 from . import noninteractive, compete, get_source
 
 from .examples import (
-    dumb_player, err_divzero, err_syntax, err_badfun, err_oom, err_timeout
+    dumb_player, err_divzero, err_syntax, err_badfun, err_oom, err_timeout,
+    err_nothing
 )
 
 
@@ -36,12 +37,24 @@ class NonInteractive(TestCase):
         r = assert_error_o(self, *compete_res)
         self.assertIn("timeout", r)
 
+    def test_error_nothing_x(self):
+        compete_res = compete(err_nothing, dumb_player)
+        self.assertIn("got nil", assert_error_x(self, *compete_res))
 
-@skipUnless(os.path.isdir('/sys/fs/cgroup/memory/tictactoe'), 'no cgroups')
+
+
+SKIPMSG = 'no tictactoe cgroup'
+@skipUnless(os.path.isdir('/sys/fs/cgroup/memory/tictactoe'), SKIPMSG)
 class MemoryTestCase(TestCase):
-    def test_error_oom(self):
-        onek = 1 << 20  # 1M
-        compete_res = compete(dumb_player, err_oom, memlimit=onek)
+    def test_error_oom_x(self):
+        onem = 1 << 20  # 1M
+        compete_res = compete(err_oom, dumb_player, memlimit=onem)
+        r = assert_error_x(self, *compete_res)
+        self.assertIn("probably OOM", r)
+
+    def test_error_oom_o(self):
+        onem = 1 << 20  # 1M
+        compete_res = compete(dumb_player, err_oom, memlimit=onem)
         r = assert_error_o(self, *compete_res)
         self.assertIn("probably OOM", r)
 
@@ -68,8 +81,6 @@ def assert_error_o(self, error, guilty, reason, gameplay):
     self.assertEqual([1, 0], gameplay)
     return reason
 
-
 def load_tests(loader, tests, ignore):
     tests.addTests(doctest.DocTestSuite(noninteractive))
     return tests
-
